django-embed-video documentation
================================

Django app for easy embedding YouTube and Vimeo videos and music from SoundCloud.

Repository is located on GitHub:

https://github.com/jazzband/django-embed-video


Contents
========

.. toctree::
   :maxdepth: 2
   :glob:

   installation
   examples
   example-project
   development/index
   websites
   changes


Library API
===========

.. toctree::
   :maxdepth: 2

   api/index


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

